( cd usr/lib ; rm -rf libmono.so.0 )
( cd usr/lib ; ln -sf libmono.so.0.0.0 libmono.so.0 )
( cd usr/lib ; rm -rf libmono.so )
( cd usr/lib ; ln -sf libmono.so.0.0.0 libmono.so )
( cd usr/lib ; rm -rf libmono-profiler-cov.so.0 )
( cd usr/lib ; ln -sf libmono-profiler-cov.so.0.0.0 libmono-profiler-cov.so.0 )
( cd usr/lib ; rm -rf libmono-profiler-cov.so )
( cd usr/lib ; ln -sf libmono-profiler-cov.so.0.0.0 libmono-profiler-cov.so )
( cd usr/lib ; rm -rf libmono-profiler-aot.so.0 )
( cd usr/lib ; ln -sf libmono-profiler-aot.so.0.0.0 libmono-profiler-aot.so.0 )
( cd usr/lib ; rm -rf libmono-profiler-aot.so )
( cd usr/lib ; ln -sf libmono-profiler-aot.so.0.0.0 libmono-profiler-aot.so )
( cd usr/lib/mono/1.0 ; rm -rf System.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/System/1.0.5000.0__b77a5c561934e089/System.dll System.dll )
( cd usr/lib/mono/1.0 ; rm -rf System.Xml.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/System.Xml/1.0.5000.0__b77a5c561934e089/System.Xml.dll System.Xml.dll )
( cd usr/lib/mono/1.0 ; rm -rf Mono.Security.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/Mono.Security/1.0.5000.0__0738eb9f132ed756/Mono.Security.dll Mono.Security.dll )
( cd usr/lib/mono/1.0 ; rm -rf System.Security.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/System.Security/1.0.5000.0__b03f5f7f11d50a3a/System.Security.dll System.Security.dll )
( cd usr/lib/mono/1.0 ; rm -rf I18N.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/I18N/1.0.5000.0__0738eb9f132ed756/I18N.dll I18N.dll )
( cd usr/lib/mono/1.0 ; rm -rf I18N.West.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/I18N.West/1.0.5000.0__0738eb9f132ed756/I18N.West.dll I18N.West.dll )
( cd usr/lib/mono/1.0 ; rm -rf I18N.MidEast.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/I18N.MidEast/1.0.5000.0__0738eb9f132ed756/I18N.MidEast.dll I18N.MidEast.dll )
( cd usr/lib/mono/1.0 ; rm -rf I18N.Other.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/I18N.Other/1.0.5000.0__0738eb9f132ed756/I18N.Other.dll I18N.Other.dll )
( cd usr/lib/mono/1.0 ; rm -rf I18N.Rare.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/I18N.Rare/1.0.5000.0__0738eb9f132ed756/I18N.Rare.dll I18N.Rare.dll )
( cd usr/lib/mono/1.0 ; rm -rf I18N.CJK.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/I18N.CJK/1.0.5000.0__0738eb9f132ed756/I18N.CJK.dll I18N.CJK.dll )
( cd usr/lib/mono/1.0 ; rm -rf System.Drawing.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/System.Drawing/1.0.5000.0__b03f5f7f11d50a3a/System.Drawing.dll System.Drawing.dll )
( cd usr/lib/mono/1.0 ; rm -rf System.EnterpriseServices.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/System.EnterpriseServices/1.0.5000.0__b03f5f7f11d50a3a/System.EnterpriseServices.dll System.EnterpriseServices.dll )
( cd usr/lib/mono/1.0 ; rm -rf Mono.Data.Tds.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/Mono.Data.Tds/1.0.5000.0__0738eb9f132ed756/Mono.Data.Tds.dll Mono.Data.Tds.dll )
( cd usr/lib/mono/1.0 ; rm -rf System.Data.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/System.Data/1.0.5000.0__b77a5c561934e089/System.Data.dll System.Data.dll )
( cd usr/lib/mono/1.0 ; rm -rf Mono.Data.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/Mono.Data/1.0.5000.0__0738eb9f132ed756/Mono.Data.dll Mono.Data.dll )
( cd usr/lib/mono/1.0 ; rm -rf Mono.GetOptions.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/Mono.GetOptions/1.0.5000.0__0738eb9f132ed756/Mono.GetOptions.dll Mono.GetOptions.dll )
( cd usr/lib/mono/1.0 ; rm -rf System.Web.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/System.Web/1.0.5000.0__b03f5f7f11d50a3a/System.Web.dll System.Web.dll )
( cd usr/lib/mono/1.0 ; rm -rf System.Web.Services.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/System.Web.Services/1.0.5000.0__b03f5f7f11d50a3a/System.Web.Services.dll System.Web.Services.dll )
( cd usr/lib/mono/1.0 ; rm -rf System.Runtime.Serialization.Formatters.Soap.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/System.Runtime.Serialization.Formatters.Soap/1.0.5000.0__b03f5f7f11d50a3a/System.Runtime.Serialization.Formatters.Soap.dll System.Runtime.Serialization.Formatters.Soap.dll )
( cd usr/lib/mono/1.0 ; rm -rf System.Runtime.Remoting.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/System.Runtime.Remoting/1.0.5000.0__b77a5c561934e089/System.Runtime.Remoting.dll System.Runtime.Remoting.dll )
( cd usr/lib/mono/1.0 ; rm -rf System.Configuration.Install.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/System.Configuration.Install/1.0.5000.0__b03f5f7f11d50a3a/System.Configuration.Install.dll System.Configuration.Install.dll )
( cd usr/lib/mono/1.0 ; rm -rf System.Management.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/System.Management/1.0.5000.0__b03f5f7f11d50a3a/System.Management.dll System.Management.dll )
( cd usr/lib/mono/1.0 ; rm -rf Mono.CompilerServices.SymbolWriter.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/Mono.CompilerServices.SymbolWriter/1.0.5000.0__0738eb9f132ed756/Mono.CompilerServices.SymbolWriter.dll Mono.CompilerServices.SymbolWriter.dll )
( cd usr/lib/mono/1.0 ; rm -rf Mono.Posix.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/Mono.Posix/1.0.5000.0__0738eb9f132ed756/Mono.Posix.dll Mono.Posix.dll )
( cd usr/lib/mono/1.0 ; rm -rf Mono.Data.SqliteClient.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/Mono.Data.SqliteClient/1.0.5000.0__0738eb9f132ed756/Mono.Data.SqliteClient.dll Mono.Data.SqliteClient.dll )
( cd usr/lib/mono/1.0 ; rm -rf Mono.Data.SybaseClient.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/Mono.Data.SybaseClient/1.0.5000.0__0738eb9f132ed756/Mono.Data.SybaseClient.dll Mono.Data.SybaseClient.dll )
( cd usr/lib/mono/1.0 ; rm -rf Mono.Data.TdsClient.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/Mono.Data.TdsClient/1.0.5000.0__0738eb9f132ed756/Mono.Data.TdsClient.dll Mono.Data.TdsClient.dll )
( cd usr/lib/mono/1.0 ; rm -rf System.Data.OracleClient.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/System.Data.OracleClient/1.0.5000.0__b77a5c561934e089/System.Data.OracleClient.dll System.Data.OracleClient.dll )
( cd usr/lib/mono/1.0 ; rm -rf Accessibility.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/Accessibility/1.0.5000.0__b03f5f7f11d50a3a/Accessibility.dll Accessibility.dll )
( cd usr/lib/mono/1.0 ; rm -rf Microsoft.VisualC.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/Microsoft.VisualC/7.0.5000.0__b03f5f7f11d50a3a/Microsoft.VisualC.dll Microsoft.VisualC.dll )
( cd usr/lib/mono/1.0 ; rm -rf cscompmgd.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/cscompmgd/7.0.5000.0__b03f5f7f11d50a3a/cscompmgd.dll cscompmgd.dll )
( cd usr/lib/mono/1.0 ; rm -rf System.Windows.Forms.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/System.Windows.Forms/1.0.5000.0__b77a5c561934e089/System.Windows.Forms.dll System.Windows.Forms.dll )
( cd usr/lib/mono/1.0 ; rm -rf Microsoft.VisualBasic.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/Microsoft.VisualBasic/7.0.5000.0__b03f5f7f11d50a3a/Microsoft.VisualBasic.dll Microsoft.VisualBasic.dll )
( cd usr/lib/mono/1.0 ; rm -rf System.Design.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/System.Design/1.0.5000.0__b03f5f7f11d50a3a/System.Design.dll System.Design.dll )
( cd usr/lib/mono/1.0 ; rm -rf PEAPI.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/PEAPI/1.0.5000.0__0738eb9f132ed756/PEAPI.dll PEAPI.dll )
( cd usr/lib/mono/1.0 ; rm -rf Npgsql.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/Npgsql/1.0.5000.0__5d8b90d52f46fda7/Npgsql.dll Npgsql.dll )
( cd usr/lib/mono/1.0 ; rm -rf ICSharpCode.SharpZipLib.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/ICSharpCode.SharpZipLib/0.84.0.0__1b03e6acf1164f73/ICSharpCode.SharpZipLib.dll ICSharpCode.SharpZipLib.dll )
( cd usr/lib/mono/1.0 ; rm -rf ByteFX.Data.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/ByteFX.Data/0.7.6.1__0738eb9f132ed756/ByteFX.Data.dll ByteFX.Data.dll )
( cd usr/lib/mono/1.0 ; rm -rf Commons.Xml.Relaxng.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/Commons.Xml.Relaxng/1.0.5000.0__0738eb9f132ed756/Commons.Xml.Relaxng.dll Commons.Xml.Relaxng.dll )
( cd usr/lib/mono/1.0 ; rm -rf Novell.Directory.Ldap.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/Novell.Directory.Ldap/1.0.5000.0__0738eb9f132ed756/Novell.Directory.Ldap.dll Novell.Directory.Ldap.dll )
( cd usr/lib/mono/1.0 ; rm -rf Mono.Security.Win32.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/Mono.Security.Win32/1.0.5000.0__0738eb9f132ed756/Mono.Security.Win32.dll Mono.Security.Win32.dll )
( cd usr/lib/mono/1.0 ; rm -rf System.DirectoryServices.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/System.DirectoryServices/1.0.5000.0__b03f5f7f11d50a3a/System.DirectoryServices.dll System.DirectoryServices.dll )
( cd usr/lib/mono/1.0 ; rm -rf System.Messaging.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/System.Messaging/1.0.5000.0__b03f5f7f11d50a3a/System.Messaging.dll System.Messaging.dll )
( cd usr/lib/mono/1.0 ; rm -rf System.ServiceProcess.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/System.ServiceProcess/1.0.5000.0__b03f5f7f11d50a3a/System.ServiceProcess.dll System.ServiceProcess.dll )
( cd usr/lib/mono/1.0 ; rm -rf System.Drawing.Design.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/System.Drawing.Design/1.0.5000.0__b03f5f7f11d50a3a/System.Drawing.Design.dll System.Drawing.Design.dll )
( cd usr/lib/mono/1.0 ; rm -rf Mono.Http.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/Mono.Http/1.0.5000.0__0738eb9f132ed756/Mono.Http.dll Mono.Http.dll )
( cd usr/lib/mono/1.0 ; rm -rf Microsoft.Vsa.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/Microsoft.Vsa/7.0.5000.0__b03f5f7f11d50a3a/Microsoft.Vsa.dll Microsoft.Vsa.dll )
( cd usr/lib/mono/1.0 ; rm -rf Mono.Cairo.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/Mono.Cairo/1.0.5000.0__0738eb9f132ed756/Mono.Cairo.dll Mono.Cairo.dll )
( cd usr/lib/mono/1.0 ; rm -rf IBM.Data.DB2.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/IBM.Data.DB2/1.0.0.0__7c307b91aa13d208/IBM.Data.DB2.dll IBM.Data.DB2.dll )
( cd usr/lib/mono/1.0 ; rm -rf Microsoft.JScript.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/Microsoft.JScript/7.0.5000.0__b03f5f7f11d50a3a/Microsoft.JScript.dll Microsoft.JScript.dll )
( cd usr/lib/mono/1.0 ; rm -rf FirebirdSql.Data.Firebird.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/FirebirdSql.Data.Firebird/1.7.1.0__0706f5520aae4ff4/FirebirdSql.Data.Firebird.dll FirebirdSql.Data.Firebird.dll )
( cd usr/lib/mono/1.0 ; rm -rf nunit.framework.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/nunit.framework/2.2.0.0__96d09a1eb7f44a77/nunit.framework.dll nunit.framework.dll )
( cd usr/lib/mono/1.0 ; rm -rf nunit.core.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/nunit.core/2.2.0.0__96d09a1eb7f44a77/nunit.core.dll nunit.core.dll )
( cd usr/lib/mono/1.0 ; rm -rf nunit.util.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/nunit.util/2.2.0.0__96d09a1eb7f44a77/nunit.util.dll nunit.util.dll )
( cd usr/lib/mono/compat-1.0 ; rm -rf ICSharpCode.SharpZipLib.dll )
( cd usr/lib/mono/compat-1.0 ; ln -sf ../gac/ICSharpCode.SharpZipLib/0.6.0.0__1b03e6acf1164f73/ICSharpCode.SharpZipLib.dll ICSharpCode.SharpZipLib.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System/2.0.0.0__b77a5c561934e089/System.dll System.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Xml.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Xml/2.0.0.0__b77a5c561934e089/System.Xml.dll System.Xml.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.Security.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.Security/2.0.0.0__0738eb9f132ed756/Mono.Security.dll Mono.Security.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Security.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Security/2.0.0.0__b03f5f7f11d50a3a/System.Security.dll System.Security.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Configuration.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Configuration/2.0.0.0__b03f5f7f11d50a3a/System.Configuration.dll System.Configuration.dll )
( cd usr/lib/mono/2.0 ; rm -rf I18N.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/I18N/2.0.0.0__0738eb9f132ed756/I18N.dll I18N.dll )
( cd usr/lib/mono/2.0 ; rm -rf I18N.West.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/I18N.West/2.0.0.0__0738eb9f132ed756/I18N.West.dll I18N.West.dll )
( cd usr/lib/mono/2.0 ; rm -rf I18N.MidEast.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/I18N.MidEast/2.0.0.0__0738eb9f132ed756/I18N.MidEast.dll I18N.MidEast.dll )
( cd usr/lib/mono/2.0 ; rm -rf I18N.Other.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/I18N.Other/2.0.0.0__0738eb9f132ed756/I18N.Other.dll I18N.Other.dll )
( cd usr/lib/mono/2.0 ; rm -rf I18N.Rare.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/I18N.Rare/2.0.0.0__0738eb9f132ed756/I18N.Rare.dll I18N.Rare.dll )
( cd usr/lib/mono/2.0 ; rm -rf I18N.CJK.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/I18N.CJK/2.0.0.0__0738eb9f132ed756/I18N.CJK.dll I18N.CJK.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Drawing.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Drawing/2.0.0.0__b03f5f7f11d50a3a/System.Drawing.dll System.Drawing.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.EnterpriseServices.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.EnterpriseServices/2.0.0.0__b03f5f7f11d50a3a/System.EnterpriseServices.dll System.EnterpriseServices.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.C5.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.C5/0.5.1.1__ba07f434b1c35cbd/Mono.C5.dll Mono.C5.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.Data.Tds.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.Data.Tds/2.0.0.0__0738eb9f132ed756/Mono.Data.Tds.dll Mono.Data.Tds.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Data.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Data/2.0.0.0__b77a5c561934e089/System.Data.dll System.Data.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.Data.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.Data/2.0.0.0__0738eb9f132ed756/Mono.Data.dll Mono.Data.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.GetOptions.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.GetOptions/2.0.0.0__0738eb9f132ed756/Mono.GetOptions.dll Mono.GetOptions.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Web.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Web/2.0.0.0__b03f5f7f11d50a3a/System.Web.dll System.Web.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Web.Services.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Web.Services/2.0.0.0__b03f5f7f11d50a3a/System.Web.Services.dll System.Web.Services.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Runtime.Serialization.Formatters.Soap.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Runtime.Serialization.Formatters.Soap/2.0.0.0__b03f5f7f11d50a3a/System.Runtime.Serialization.Formatters.Soap.dll System.Runtime.Serialization.Formatters.Soap.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Runtime.Remoting.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Runtime.Remoting/2.0.0.0__b77a5c561934e089/System.Runtime.Remoting.dll System.Runtime.Remoting.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Configuration.Install.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Configuration.Install/2.0.0.0__b03f5f7f11d50a3a/System.Configuration.Install.dll System.Configuration.Install.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Management.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Management/2.0.0.0__b03f5f7f11d50a3a/System.Management.dll System.Management.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.CompilerServices.SymbolWriter.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.CompilerServices.SymbolWriter/2.0.0.0__0738eb9f132ed756/Mono.CompilerServices.SymbolWriter.dll Mono.CompilerServices.SymbolWriter.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.Posix.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.Posix/2.0.0.0__0738eb9f132ed756/Mono.Posix.dll Mono.Posix.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.Data.SqliteClient.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.Data.SqliteClient/2.0.0.0__0738eb9f132ed756/Mono.Data.SqliteClient.dll Mono.Data.SqliteClient.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.Data.SybaseClient.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.Data.SybaseClient/2.0.0.0__0738eb9f132ed756/Mono.Data.SybaseClient.dll Mono.Data.SybaseClient.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.Data.TdsClient.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.Data.TdsClient/2.0.0.0__0738eb9f132ed756/Mono.Data.TdsClient.dll Mono.Data.TdsClient.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Data.OracleClient.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Data.OracleClient/2.0.0.0__b77a5c561934e089/System.Data.OracleClient.dll System.Data.OracleClient.dll )
( cd usr/lib/mono/2.0 ; rm -rf Accessibility.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Accessibility/2.0.0.0__b03f5f7f11d50a3a/Accessibility.dll Accessibility.dll )
( cd usr/lib/mono/2.0 ; rm -rf Microsoft.VisualC.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Microsoft.VisualC/8.0.0.0__b03f5f7f11d50a3a/Microsoft.VisualC.dll Microsoft.VisualC.dll )
( cd usr/lib/mono/2.0 ; rm -rf cscompmgd.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/cscompmgd/8.0.0.0__b03f5f7f11d50a3a/cscompmgd.dll cscompmgd.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Windows.Forms.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Windows.Forms/2.0.0.0__b77a5c561934e089/System.Windows.Forms.dll System.Windows.Forms.dll )
( cd usr/lib/mono/2.0 ; rm -rf Microsoft.VisualBasic.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Microsoft.VisualBasic/8.0.0.0__b03f5f7f11d50a3a/Microsoft.VisualBasic.dll Microsoft.VisualBasic.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Design.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Design/2.0.0.0__b03f5f7f11d50a3a/System.Design.dll System.Design.dll )
( cd usr/lib/mono/2.0 ; rm -rf PEAPI.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/PEAPI/2.0.0.0__0738eb9f132ed756/PEAPI.dll PEAPI.dll )
( cd usr/lib/mono/2.0 ; rm -rf Npgsql.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Npgsql/2.0.0.0__5d8b90d52f46fda7/Npgsql.dll Npgsql.dll )
( cd usr/lib/mono/2.0 ; rm -rf ICSharpCode.SharpZipLib.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/ICSharpCode.SharpZipLib/2.84.0.0__1b03e6acf1164f73/ICSharpCode.SharpZipLib.dll ICSharpCode.SharpZipLib.dll )
( cd usr/lib/mono/2.0 ; rm -rf ByteFX.Data.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/ByteFX.Data/0.7.6.2__0738eb9f132ed756/ByteFX.Data.dll ByteFX.Data.dll )
( cd usr/lib/mono/2.0 ; rm -rf Commons.Xml.Relaxng.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Commons.Xml.Relaxng/2.0.0.0__0738eb9f132ed756/Commons.Xml.Relaxng.dll Commons.Xml.Relaxng.dll )
( cd usr/lib/mono/2.0 ; rm -rf Novell.Directory.Ldap.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Novell.Directory.Ldap/2.0.0.0__0738eb9f132ed756/Novell.Directory.Ldap.dll Novell.Directory.Ldap.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.Security.Win32.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.Security.Win32/2.0.0.0__0738eb9f132ed756/Mono.Security.Win32.dll Mono.Security.Win32.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.DirectoryServices.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.DirectoryServices/2.0.0.0__b03f5f7f11d50a3a/System.DirectoryServices.dll System.DirectoryServices.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Messaging.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Messaging/2.0.0.0__b03f5f7f11d50a3a/System.Messaging.dll System.Messaging.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.ServiceProcess.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.ServiceProcess/2.0.0.0__b03f5f7f11d50a3a/System.ServiceProcess.dll System.ServiceProcess.dll )
( cd usr/lib/mono/2.0 ; rm -rf System.Drawing.Design.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/System.Drawing.Design/2.0.0.0__b03f5f7f11d50a3a/System.Drawing.Design.dll System.Drawing.Design.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.Http.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.Http/2.0.0.0__0738eb9f132ed756/Mono.Http.dll Mono.Http.dll )
( cd usr/lib/mono/2.0 ; rm -rf Microsoft.Vsa.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Microsoft.Vsa/8.0.0.0__b03f5f7f11d50a3a/Microsoft.Vsa.dll Microsoft.Vsa.dll )
( cd usr/lib/mono/2.0 ; rm -rf Mono.Cairo.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.Cairo/2.0.0.0__0738eb9f132ed756/Mono.Cairo.dll Mono.Cairo.dll )
( cd usr/lib/mono/2.0 ; rm -rf Microsoft.JScript.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Microsoft.JScript/8.0.0.0__b03f5f7f11d50a3a/Microsoft.JScript.dll Microsoft.JScript.dll )
( cd usr/lib/mono/2.0 ; rm -rf Microsoft.Build.Framework.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Microsoft.Build.Framework/2.0.0.0__b03f5f7f11d50a3a/Microsoft.Build.Framework.dll Microsoft.Build.Framework.dll )
( cd usr/lib/mono/2.0 ; rm -rf Microsoft.Build.Utilities.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Microsoft.Build.Utilities/2.0.0.0__b03f5f7f11d50a3a/Microsoft.Build.Utilities.dll Microsoft.Build.Utilities.dll )
( cd usr/lib/mono/2.0 ; rm -rf Microsoft.Build.Engine.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Microsoft.Build.Engine/2.0.0.0__b03f5f7f11d50a3a/Microsoft.Build.Engine.dll Microsoft.Build.Engine.dll )
( cd usr/lib/mono/2.0 ; rm -rf Microsoft.Build.Tasks.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Microsoft.Build.Tasks/2.0.0.0__b03f5f7f11d50a3a/Microsoft.Build.Tasks.dll Microsoft.Build.Tasks.dll )
( cd usr/lib/mono/compat-2.0 ; rm -rf ICSharpCode.SharpZipLib.dll )
( cd usr/lib/mono/compat-2.0 ; ln -sf ../gac/ICSharpCode.SharpZipLib/2.6.0.0__1b03e6acf1164f73/ICSharpCode.SharpZipLib.dll ICSharpCode.SharpZipLib.dll )
